;Installer for additional Gimp plugins

;gimp version
#define minversion='2.4.0'

;#define dontcompress

;#define SPANNED
;#define ENGLISH_ONLY
;#define VERSION="test"

#ifndef VERSION
	#error Version not specified
#endif

[Setup]
AppName=The GIMP
AppID=WinGimp-2.0
AppVerName=GIMP Help 2-{#VERSION}
AppPublisherURL=http://www.gimp.org/win32/
AppSupportURL=http://groups.yahoo.com/group/gimpwin-users/
AppUpdatesURL=http://gimp-win.sourceforge.net/
DefaultDirName={code:GetGimpDir|null}
DisableProgramGroupPage=yes
DisableDirPage=yes
FlatComponentsList=yes
;LicenseFile=gpl.rtf
;InfoBeforeFile=faq.rtf
;ChangesAssociations=true
WizardImageFile=big.bmp
WizardImageBackColor=$ffffff
WizardSmallImageFile=small.bmp
WizardImageStretch=no
CreateUninstallRegKey=no
UpdateUninstallLogAppName=no
UninstallFilesDir={code:GetUninstallDir}
#if defined(SPANNED) && !defined(ENGLISH_ONLY)
DiskSpanning=yes
DiskSliceSize={#SPANSLICESIZE}
ReserveBytes=9592
OutputDir=_Output\Spanned
Compression=lzma/ultra
InternalCompressLevel=ultra
SolidCompression=yes
OutputBaseFilename=gimp-help-2-{#VERSION}-setup
UseSetupLdr=yes
#elif defined(dontcompress) && !defined(ENGLISH_ONLY)
UseSetupLdr=no
OutputDir=_Output\47z
Compression=none
InternalCompressLevel=0
#else
OutputDir=_Output
Compression=lzma/ultra
InternalCompressLevel=ultra
SolidCompression=yes
#if defined(ENGLISH_ONLY)
OutputBaseFilename=gimp-help-2-{#VERSION}-eng-setup
#else
OutputBaseFilename=gimp-help-2-{#VERSION}-setup
#endif
#endif

[Languages]
Name: "en"; MessagesFile: "compiler:Default.isl,en.help.isl"

[Messages]
WelcomeLabel1=Welcome to the GIMP Help Setup Wizard

#if !defined(ENGLISH_ONLY)
[Types]
Name: full; Description: Full
Name: minimal; Description: Minimal
Name: custom; Description: Custom; Flags: IsCustom

[Components]
Name: "en"; Description: "English"; Types: full minimal custom; Flags: fixed
 #include "languages1.ish"
 #define COMPONENTS_EN='Components: en'
#else
 #define COMPONENTS_EN=''
#endif

[Files]
#if !defined(ENGLISH_ONLY)
 #include "languages2.ish"
#else
Source: "help\en\*.*"; DestDir: "{app}\share\gimp\2.0\help\en"; Flags: recursesubdirs comparetimestamp; {#COMPONENTS_EN}
 #include "languages3.ish"
#endif

[Code]
const
  RegPath = 'SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\WinGimp-2.0_is1';
  RegKey = 'Inno Setup: App Path';
  VerKey = 'DisplayName';

var
  GimpPath: String;
  GimpVer: String;

function Count(What, Where: String): Integer;
begin
	Result := 0;
	if Length(What) = 0 then
		exit; //avoid infinite loop
	while Pos(What,Where)>0 do
	begin
		Where := Copy(Where,Pos(What,Where)+Length(What),Length(Where));
		Result := Result + 1;
	end;
end;


//split text to array
procedure Explode(var ADest: TArrayOfString; aText, aSeparator: String);
var tmp: Integer;
begin
	if aSeparator='' then
		exit;

	SetArrayLength(ADest,Count(aSeparator,aText)+1)

	tmp := 0;
	repeat
		if Pos(aSeparator,aText)>0 then
		begin

			ADest[tmp] := Copy(aText,1,Pos(aSeparator,aText)-1);
			aText := Copy(aText,Pos(aSeparator,aText)+Length(aSeparator),Length(aText));
			tmp := tmp + 1;

		end else
		begin

			 ADest[tmp] := aText;
			 aText := '';

		end;
	until Length(aText)=0;
end;



//compares two version numbers, returns -1 if vA is newer, 0 if both are identical, 1 if vB is newer
function CompareVersion(vA,vB: String): Integer;
var tmp: TArrayOfString;
	verA,verB: Array of Integer;
	i,len: Integer;
begin

	StringChange(vA,'-','.');
	StringChange(vB,'-','.');

	Explode(tmp,vA,'.');
	SetArrayLength(verA,GetArrayLength(tmp));
	for i := 0 to GetArrayLength(tmp) - 1 do
		verA[i] := StrToIntDef(tmp[i],0);
		
	Explode(tmp,vB,'.');
	SetArrayLength(verB,GetArrayLength(tmp));
	for i := 0 to GetArrayLength(tmp) - 1 do
		verB[i] := StrToIntDef(tmp[i],0);

	len := GetArrayLength(verA);
	if GetArrayLength(verB) < len then
		len := GetArrayLength(verB);

	for i := 0 to len - 1 do
		if verA[i] < verB[i] then
		begin
			Result := 1;
			exit;
		end else
		if verA[i] > verB[i] then
		begin
			Result := -1;
			exit
		end;

	if GetArrayLength(verA) < GetArrayLength(verB) then
	begin
		Result := 1;
		exit;
	end else
	if GetArrayLength(verA) > GetArrayLength(verB) then
	begin
		Result := -1;
		exit;
	end;

	Result := 0;

end;


function InitializeSetup(): Boolean;
var p: Integer;
begin
  Result := True;
  GimpPath := '';
  If not RegQueryStringValue(HKLM, RegPath, RegKey, GimpPath) then //find Gimp
    if not RegQueryStringValue(HKCU, RegPath, RegKey, GimpPath) then         //install dir
    begin
      Result := False;
      MsgBox('Gimp 2.0 installation path could not be read from the Registry. Please install Gimp {#=minversion} or later first.', mbError, 0);
      exit;
    end;

  If not RegQueryStringValue(HKLM, RegPath, VerKey, GimpVer) then //find Gimp
    if not RegQueryStringValue(HKCU, RegPath, VerKey, GimpVer) then         //install dir
    begin
    	Result := False;
      MsgBox('Gimp 2.0 version could not be read from the Registry. Please install Gimp {#=minversion} or later first.', mbError, 0);
      exit;
    end;
    
  if GimpVer <> '' then
  begin
  	p := Pos('gimp',LowerCase(GimpVer));
  	GimpVer := Copy(GimpVer,p+5,Length(GimpVer));

   	if CompareVersion(GimpVer,'{#=minversion}') > 0 then
   	begin
    	Result := False;
      MsgBox('The GIMP ' + GimpVer + ' was found installed. To install help, you need Gimp {#=minversion} or later.', mbError, 0);
      exit;
 	  end;
  end;

end;

function GetGimpDir(S: String): String;
begin
	Result := GimpPath;
end;

function UpdateReadyMemo(Space, NewLine, MemoUserInfo, MemoDirInfo, MemoTypeInfo, MemoComponentsInfo, MemoGroupInfo, MemoTasksInfo: String): String;
var S: String;
    ShowAssoc: Boolean;
begin

  (* Fill the 'Ready Memo' with setup information *)

  S := 'Gimp 2 was found in:' + NewLine + Space + GetGimpDir('') + NewLine + NewLine;                //installation directory

  S := S + MemoTypeInfo + NewLine + NewLine;           //installation type (full/compact/custom)

  S := S + MemoComponentsInfo + NewLine + NewLine;     //selected components

  Result := S;
end;

function GetUninstallDir(default: String): String;
begin
	if CompareVersion(GimpVer,'2.4.0') >= 0 then
		Result := ExpandConstant('{app}')
	else
		Result := ExpandConstant('{app}\setup');
end;

#expr SaveToFile(AddBackslash(SourcePath) + "Preprocessed.iss")
